@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Access to the Hooktheory API
 
-our $VERSION = '0.02';
+our $VERSION = '0.0201';
 
 use Moo;
 use strictures 2;
@@ -83,7 +83,7 @@ sub _handle_response {
 
     if ( my $res = $tx->success ) {
         my $body = $res->body;
-        if ( $body =~ /^{/ && $body =~ /}$/ ) {
+        if ( $body =~ /{/ ) {
             $data = decode_json( $res->body );
         }
         else {
@@ -114,7 +114,7 @@ WebService::Hooktheory - Access to the Hooktheory API
 
 =head1 VERSION
 
-version 0.02
+version 0.0201
 
 =head1 SYNOPSIS
 
